---
# generated by https://github.com/hashicorp/terraform-plugin-docs
page_title: "smallstep_provisioner_webhook Data Source - terraform-provider-smallstep"
subcategory: ""
description: |-
  A webhook https://smallstep.com/docs/step-ca/webhooks/ to call when a certificate request is being processed.
---

# smallstep_provisioner_webhook (Data Source)

A [webhook](https://smallstep.com/docs/step-ca/webhooks/) to call when a certificate request is being processed.

## Example Usage

```terraform
data "smallstep_provisioner_webhook" "hook" {
  authority_id   = "efc93152-1f4d-4f18-96d6-0c766b01063f"
  provisioner_id = "8c28e503-e57b-456b-b6fc-7abfca973f98"
  id             = "devices"
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `authority_id` (String)
- `provisioner_id` (String)

### Optional

- `id` (String) UUID identifying this webhook. Generated server-side when the webhook is created. Will be sent to the webhook server in every request in the `X-Smallstep-Webhook-ID` header.
- `name` (String) The name of the webhook. For `ENRICHING` webhooks, the returned data can be referenced in the certificate under the path `.Webhooks.<name>`. Must be unique to the provisioner.

### Read-Only

- `cert_type` (String) Allowed values: `ALL` `X509` `SSH`
- `disable_tls_client_auth` (Boolean) The CA will not send a client certificate when requested by the webhook server. Optional for `EXTERNAL` webhook servers; not allowed with hosted webhook servers.
- `kind` (String) The webhook kind indicates how and when it is called.

ENRICHING webhooks are called before rendering the certificate template. They have two functions. First, they must allow the certificate request or it will be aborted. Second, they can return additional data to be referenced in the certificate template. The payload sent to the webhook server varies based on whether an X509 or SSH certificate is to be signed and based on the type of provisioner.
 Allowed values: `ENRICHING`
- `server_type` (String) An EXTERNAL webhook server is not operated by Smallstep. The caller must use the returned ID and secret to configure the server.

A HOSTED_ATTESTATION webhook server is hosted by Smallstep and must be used with an `ENRICHING` webhook type and an ACME Attestation provisioner. The webhook server will verify the attested permanent identifier exists as the ID of an instance in the configured collection. The data of the instance in the collection will be added to the template data.
 Allowed values: `EXTERNAL` `HOSTED_ATTESTATION`
- `url` (String) The URL of the webhook server. Required for `EXTERNAL` webhook servers; read-only for hosted webhook servers.


