---
# generated by https://github.com/hashicorp/terraform-plugin-docs
page_title: "smallstep_authority Resource - terraform-provider-smallstep"
subcategory: ""
description: |-
  An X509 authority hosted by Smallstep.
---

# smallstep_authority (Resource)

An X509 authority hosted by Smallstep.

## Example Usage

```terraform
resource "smallstep_authority" "basic" {
  type              = "devops"
  active_revocation = false
  admin_emails      = ["eng@smallstep.com"]
  name              = "Basic"
  subdomain         = "basic"
}

output "bootstrap_basic" {
  value = "step ca bootstrap --ca-url https://${smallstep_authority.basic.domain} --fingerprint ${smallstep_authority.basic.fingerprint} --context basic"
}

resource "smallstep_authority" "advanced" {
  subdomain         = "myadvanced"
  name              = "My Advanced Authority"
  type              = "advanced"
  admin_emails      = ["eng@smallstep.com"]
  active_revocation = true
  intermediate_issuer = {
    name            = "My Custom Intermediate"
    key_version     = "RSA_SIGN_PKCS1_2048_SHA256"
    duration        = "100h"
    max_path_length = 0
    name_constraints = {
      critical                  = true
      permitted_ip_ranges       = ["10.32.0.0/12"]
      permitted_dns_domains     = [".cluster.local"]
      permitted_email_addresses = ["eng@smallstep.com"]
      permitted_uri_domains     = ["uri.cluster.local"]
    }
    subject = {
      common_name         = "Issuer"
      country             = "US"
      email_address       = "test@smallstep.com"
      locality            = "San Francisco"
      organization        = "Engineering"
      organizational_unit = "Core"
      postal_code         = "94108"
      province            = "CA"
      serial_number       = "1"
      street_address      = "26 O'Farrell St"
    }
  }
  root_issuer = {
    name            = "My Custom Root"
    key_version     = "RSA_SIGN_PKCS1_2048_SHA256"
    duration        = "1000h"
    max_path_length = "1"
    name_constraints = {
      critical                 = false
      excluded_ip_ranges       = ["10.96.0.0/12"]
      excluded_dns_domains     = ["example.com"]
      excluded_email_addresses = ["eng@example.com"]
      excluded_uri_domains     = ["uri:example.com"]
    }
  }
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `admin_emails` (Set of String)
- `name` (String) The name of the authority.
- `subdomain` (String) The domain where the authority can be reached.
- `type` (String) One of the available authority types
 Allowed values: `devops` `advanced` `managed`

### Optional

- `active_revocation` (Boolean) Whether CRL and OCSP are enabled (advanced authorities only).
- `intermediate_issuer` (Attributes) (see [below for nested schema](#nestedatt--intermediate_issuer))
- `root_issuer` (Attributes) (see [below for nested schema](#nestedatt--root_issuer))

### Read-Only

- `created_at` (String) Timestamp when the authority was created.
- `domain` (String) The domain where the authority can be reached.
- `fingerprint` (String) The SHA-256 digest of the authority's root certificate in hex format.
- `id` (String) A UUID identifying this authority.
- `root` (String) The root certificate in pem format.

<a id="nestedatt--intermediate_issuer"></a>
### Nested Schema for `intermediate_issuer`

Required:

- `key_version` (String) The signature algorithm.
 Allowed values: `EC_SIGN_P256_SHA256` `EC_SIGN_P384_SHA384` `RSA_SIGN_PKCS1_2048_SHA256` `RSA_SIGN_PKCS1_3072_SHA256` `RSA_SIGN_PKCS1_4096_SHA256` `RSA_SIGN_PKCS1_4096_SHA512` `RSA_SIGN_PSS_2048_SHA256` `RSA_SIGN_PSS_3072_SHA256` `RSA_SIGN_PSS_4096_SHA256` `RSA_SIGN_PSS_4096_SHA512`
- `name` (String) The name of the issuer.

Optional:

- `duration` (String) The certificate lifetime. Parsed as a [Golang duration](https://pkg.go.dev/time#ParseDuration).
- `max_path_length` (Number)
- `name_constraints` (Attributes) X509 certificate name constratins. (see [below for nested schema](#nestedatt--intermediate_issuer--name_constraints))
- `subject` (Attributes) Name used in x509 certificates (see [below for nested schema](#nestedatt--intermediate_issuer--subject))

<a id="nestedatt--intermediate_issuer--name_constraints"></a>
### Nested Schema for `intermediate_issuer.name_constraints`

Optional:

- `critical` (Boolean) Whether or not name constraints are marked critical.
- `excluded_dns_domains` (Set of String)
- `excluded_email_addresses` (Set of String)
- `excluded_ip_ranges` (Set of String)
- `excluded_uri_domains` (Set of String)
- `permitted_dns_domains` (Set of String)
- `permitted_email_addresses` (Set of String)
- `permitted_ip_ranges` (Set of String)
- `permitted_uri_domains` (Set of String)


<a id="nestedatt--intermediate_issuer--subject"></a>
### Nested Schema for `intermediate_issuer.subject`

Optional:

- `common_name` (String)
- `country` (String)
- `email_address` (String)
- `locality` (String)
- `organization` (String)
- `organizational_unit` (String)
- `postal_code` (String)
- `province` (String)
- `serial_number` (String)
- `street_address` (String)



<a id="nestedatt--root_issuer"></a>
### Nested Schema for `root_issuer`

Required:

- `key_version` (String) The signature algorithm.
 Allowed values: `EC_SIGN_P256_SHA256` `EC_SIGN_P384_SHA384` `RSA_SIGN_PKCS1_2048_SHA256` `RSA_SIGN_PKCS1_3072_SHA256` `RSA_SIGN_PKCS1_4096_SHA256` `RSA_SIGN_PKCS1_4096_SHA512` `RSA_SIGN_PSS_2048_SHA256` `RSA_SIGN_PSS_3072_SHA256` `RSA_SIGN_PSS_4096_SHA256` `RSA_SIGN_PSS_4096_SHA512`
- `name` (String) The name of the issuer.

Optional:

- `duration` (String) The certificate lifetime. Parsed as a [Golang duration](https://pkg.go.dev/time#ParseDuration).
- `max_path_length` (Number)
- `name_constraints` (Attributes) X509 certificate name constratins. (see [below for nested schema](#nestedatt--root_issuer--name_constraints))
- `subject` (Attributes) Name used in x509 certificates (see [below for nested schema](#nestedatt--root_issuer--subject))

<a id="nestedatt--root_issuer--name_constraints"></a>
### Nested Schema for `root_issuer.name_constraints`

Optional:

- `critical` (Boolean) Whether or not name constraints are marked critical.
- `excluded_dns_domains` (Set of String)
- `excluded_email_addresses` (Set of String)
- `excluded_ip_ranges` (Set of String)
- `excluded_uri_domains` (Set of String)
- `permitted_dns_domains` (Set of String)
- `permitted_email_addresses` (Set of String)
- `permitted_ip_ranges` (Set of String)
- `permitted_uri_domains` (Set of String)


<a id="nestedatt--root_issuer--subject"></a>
### Nested Schema for `root_issuer.subject`

Optional:

- `common_name` (String)
- `country` (String)
- `email_address` (String)
- `locality` (String)
- `organization` (String)
- `organizational_unit` (String)
- `postal_code` (String)
- `province` (String)
- `serial_number` (String)
- `street_address` (String)

## Import

Import is supported using the following syntax:

```shell
terraform import smallstep_authority.my_ca b1161f78-d251-401e-b17c-fe38fc26ae7b
```
