---
# generated by https://github.com/hashicorp/terraform-plugin-docs
page_title: "smallstep_device_collection Resource - terraform-provider-smallstep"
subcategory: ""
description: |-
  Configuration to create a new device collection.
---

# smallstep_device_collection (Resource)

Configuration to create a new device collection.

## Example Usage

### GCP VM Device Collection with GCE Instance

```terraform
resource "smallstep_device_collection" "gcp" {
  slug         = "gce"
  display_name = "GCE"
  device_type  = "gcp-vm"
  gcp_vm = {
    service_accounts = ["pki@prod-1234.iam.gserviceaccount.com"]
  }
  admin_emails = ["admin@example.com"]
}

data "google_compute_instance" "dbserver" {
  name = "dbserver"
  zone = "us-central1-b"
}

resource "smallstep_collection_instance" "dbserver" {
  depends_on      = [smallstep_device_collection.gcp]
  collection_slug = smallstep_device_collection.gcp.slug
  id              = data.google_compute_instance.dbserver.instance_id
  data = jsonencode({
    "hostname"   = data.google_compute_instance.dbserver.name
    "private_ip" = data.google_compute_instance.dbserver.network_interface.0.network_ip
    "public_ip"  = data.google_compute_instance.dbserver.network_interface.0.access_config[0].nat_ip
  })
}
```

### TPM Device Collection

```terraform
resource "smallstep_device_collection" "tpm" {
  slug         = "tmpservers"
  display_name = "TPM Servers"
  admin_emails = ["admin@example.com"]
  device_type  = "tpm"
  tpm = {
    attestor_roots = file("${path.module}/root.crt")
  }
}
```

### EC2 Device Collection

```terraform
resource "smallstep_device_collection" "aws" {
  slug         = "ec2west"
  display_name = "EC2 West"
  admin_emails = ["admin@example.com"]
  device_type  = "aws-vm"
  aws_vm = {
    accounts            = ["0123456789"]
    disable_custom_sans = false
  }
}
```

### Azure VM Device Collection

```terraform
resource "smallstep_device_collection" "azure" {
  slug         = "azure"
  display_name = "Azure VMs"
  admin_emails = ["admin@example.com"]
  device_type  = "azure-vm"
  azure_vm = {
    tenant_id           = "76543210"
    resource_groups     = ["0123456789"]
    disable_custom_sans = false
    audience            = ""
  }
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `admin_emails` (Set of String) Users that will have admin access to manage the agents authority, which will be created if it does not already exist. Ignored if the agent authority already exists. Never returned in API responses.
- `device_type` (String) Must match the deviceTypeConfiguration. Cannot be changed. Allowed values: `aws-vm` `azure-vm` `gcp-vm` `tpm`
- `display_name` (String)
- `slug` (String)

### Optional

- `aws_vm` (Attributes) Configuration for an AWS provisioner for a device collection of AWS VMs. (see [below for nested schema](#nestedatt--aws_vm))
- `azure_vm` (Attributes) (see [below for nested schema](#nestedatt--azure_vm))
- `gcp_vm` (Attributes) Configuration for the GCP provisioner for device collections of GCP instances. At least one service account or project ID must be set. (see [below for nested schema](#nestedatt--gcp_vm))
- `tpm` (Attributes) Configuration for a device collection of machines with TPMs. (see [below for nested schema](#nestedatt--tpm))

### Read-Only

- `id` (String) Internal use only

<a id="nestedatt--aws_vm"></a>
### Nested Schema for `aws_vm`

Required:

- `accounts` (Set of String) The list of AWS account IDs that are allowed to use an AWS cloud provisioner.

Optional:

- `disable_custom_sans` (Boolean) By default custom SANs are valid, but if this option is set to `true` only the SANs available in the instance identity document will be valid. These are the private IP and the DNS ip-<private-ip>.<region>.compute.internal.


<a id="nestedatt--azure_vm"></a>
### Nested Schema for `azure_vm`

Required:

- `resource_groups` (Set of String) The list of resource group names that are allowed to use this provisioner.
- `tenant_id` (String) The Azure account tenant ID for this provisioner. This ID is the Directory ID available in the Azure Active Directory properties.

Optional:

- `audience` (String) Defaults to https://management.azure.com/ but it can be changed if necessary.
- `disable_custom_sans` (Boolean) By default custom SANs are valid, but if this option is set to `true` only the SANs available in the token will be valid, in Azure only the virtual machine name is available.


<a id="nestedatt--gcp_vm"></a>
### Nested Schema for `gcp_vm`

Optional:

- `disable_custom_sans` (Boolean) By default custom SANs are valid, but if this option is set to `true` only the SANs available in the instance identity document will be valid, these are the DNS `<instance-name>.c.<project-id>.internal` and `<instance-name>.<zone>.c.<project-id>.internal`.
- `project_ids` (Set of String) The list of project identifiers that are allowed to use a GCP cloud provisioner.
- `service_accounts` (Set of String) The list of service accounts that are allowed to use a GCP cloud provisioner.


<a id="nestedatt--tpm"></a>
### Nested Schema for `tpm`

Optional:

- `attestor_intermediates` (String) The pem-encoded list of intermediate certificates used to build a chain of trust to verify the attestation certificates submitted by agents. Ignored if the team already has an attestation authority.
- `attestor_roots` (String) The pem-encoded list of certificates used to verify the attestation certificates submitted by agents. Ignored if the team already has an attestation authority. Required if the team does not already have an attestation authority.
- `force_cn` (Boolean) Force one of the SANs to become the Common Name, if a Common Name is not provided.
- `require_eab` (Boolean) Only ACME clients that have been preconfigured with valid EAB credentials will be able to create an account with this provisioner.
