---
# generated by https://github.com/hashicorp/terraform-plugin-docs
page_title: "smallstep_workload Resource - terraform-provider-smallstep"
subcategory: ""
description: |-
  A workload represents anything that uses a certificate.
---

# smallstep_workload (Resource)

A workload represents anything that uses a certificate.

## Example Usage

### Generic Workload on EC2

```terraform
resource "smallstep_device_collection" "ec2_west" {
  slug         = "ec2west"
  display_name = "EC2 West"
  device_type  = "aws-vm"
  aws_vm = {
    accounts = ["0123456789"]
  }
  admin_emails = ["admin@example.com"]
}

resource "smallstep_workload" "generic" {
  depends_on             = [smallstep_device_collection.ec2_west]
  workload_type          = "generic"
  device_collection_slug = resource.smallstep_device_collection.ec2_west.slug
  slug                   = "ec2generic"
  display_name           = "Generic Workload"
  admin_emails           = ["admin@example.com"]

  certificate_info = {
    type = "X509"
  }

  key_info = {
    format = "DEFAULT"
    type   = "ECDSA_P256"
  }
}
```

### Redis Workload with All Optionas

```terraform
resource "smallstep_workload" "redis" {
  depends_on             = [smallstep_device_collection.ec2_west]
  device_collection_slug = resource.smallstep_device_collection.ec2_west.slug
  workload_type          = "redis"
  slug                   = "redisec2west"
  display_name           = "Redis EC2 West"
  admin_emails           = ["admin@example.com"]

  certificate_info = {
    type      = "X509"
    duration  = "168h"
    crt_file  = "db.crt"
    key_file  = "db.key"
    root_file = "ca.crt"
    uid       = 1001
    gid       = 999
    mode      = 256
  }

  hooks = {
    renew = {
      shell = "/bin/sh"
      before = [
        "echo renewing",
      ]
      after = [
        "echo renewed",
      ]
      on_error = [
        "echo failed renew",
      ]
    }
    sign = {
      shell = "/bin/bash"
      before = [
        "echo signing",
      ]
      after = [
        "echo signed",
      ]
      on_error = [
        "echo failed sign",
      ]
    }
  }

  key_info = {
    format = "DEFAULT"
    type   = "ECDSA_P256"
  }

  reload_info = {
    method   = "SIGNAL"
    pid_file = "db.pid"
    signal   = 1
  }
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `admin_emails` (Set of String) Users that will have admin access to manage the workloads authority, which will be created if it does not already exist. Ignored if the workloads authority already exists. Never returned in responses.
- `certificate_info` (Attributes) Details on a managed certificate. (see [below for nested schema](#nestedatt--certificate_info))
- `device_collection_slug` (String) Slug of the device collection the workload will be added to.
- `display_name` (String) A friendly name for the workload. Also used as the Common Name if no static SANs are provide.
- `key_info` (Attributes) The attributes of the cryptographic key. (see [below for nested schema](#nestedatt--key_info))
- `slug` (String) Used as the identifier for the workload.
- `workload_type` (String)

### Optional

- `device_metadata_key_sans` (Set of String) SANs that will be populated from the instance data of the device in the device collection.
For example, if the device instance data in the collection is `{"internal_host": "foo.internal", "external_host", "foo.example.com"}` at the time the workload certificate is issued and this field is set to `["internal_host", "external_host"]`, then the certificate would include the SANs `foo.internal` and `foo.example.com`.
- `hooks` (Attributes) The collection of commands to run when a certificate for a managed endpoint is signed or renewed. (see [below for nested schema](#nestedatt--hooks))
- `reload_info` (Attributes) The properties used to reload a service. (see [below for nested schema](#nestedatt--reload_info))
- `static_sans` (List of String) SANs that will be added to every certificate issued for this workload. The first will be used as the default Common Name.

### Read-Only

- `id` (String) Internal use only.

<a id="nestedatt--certificate_info"></a>
### Nested Schema for `certificate_info`

Required:

- `type` (String) The type of certificate. Allowed values: `X509` `SSH_USER` `SSH_HOST`

Optional:

- `crt_file` (String) The filepath where the certificate is to be stored.
- `duration` (String) The certificate lifetime. Parsed as a [Golang duration](https://pkg.go.dev/time#ParseDuration).
- `gid` (Number) GID of the files where the certificate is stored.
- `key_file` (String) The filepath where the key is to be stored.
- `mode` (Number) Permission bits of the files where the certificate is stored.
- `root_file` (String) The filepath where the root certificate is to be stored.
- `uid` (Number) UID of the files where the certificate is stored.


<a id="nestedatt--key_info"></a>
### Nested Schema for `key_info`

Required:

- `format` (String) The format used to encode the private key. For X509 keys the default format is SEC 1 for ECDSA keys, PKCS#1 for RSA keys and PKCS#8 for ED25519 keys. For SSH keys the default format is always the OPENSSH format. Allowed values: `DEFAULT` `PKCS8` `OPENSSH` `DER`
- `type` (String) The key type used. The current DEFAULT type is ECDSA_P256. Allowed values: `DEFAULT` `ECDSA_P256` `ECDSA_P384` `ECDSA_P521` `RSA_2048` `RSA_3072` `RSA_4096` `ED25519`

Optional:

- `pub_file` (String) A CSR or SSH public key to use instead of generating one.


<a id="nestedatt--hooks"></a>
### Nested Schema for `hooks`

Optional:

- `renew` (Attributes) A list of commands to run before and after a certificate is granted. (see [below for nested schema](#nestedatt--hooks--renew))
- `sign` (Attributes) A list of commands to run before and after a certificate is granted. (see [below for nested schema](#nestedatt--hooks--sign))

<a id="nestedatt--hooks--renew"></a>
### Nested Schema for `hooks.renew`

Optional:

- `after` (List of String) List of commands to run after the operation.
- `before` (List of String) List of commands to run before the operation.
- `on_error` (List of String) List of commands to run when the operation fails.
- `shell` (String) The shell to use to execute the commands.


<a id="nestedatt--hooks--sign"></a>
### Nested Schema for `hooks.sign`

Optional:

- `after` (List of String) List of commands to run after the operation.
- `before` (List of String) List of commands to run before the operation.
- `on_error` (List of String) List of commands to run when the operation fails.
- `shell` (String) The shell to use to execute the commands.



<a id="nestedatt--reload_info"></a>
### Nested Schema for `reload_info`

Required:

- `method` (String) Ways an endpoint can reload a certificate. `AUTOMATIC` means the process is able to detect and reload new certificates automatically. `CUSTOM` means a custom command must be run to trigger the workload to reload the certificates. `SIGNAL` will configure the agent to send a signal to the process in `pidFile`. `DBUS` will use the systemd system bus to issue a `try-reload-or-restart` job for unit specified by `unitName`. Allowed values: `AUTOMATIC` `CUSTOM` `SIGNAL` `DBUS`

Optional:

- `pid_file` (String) File that holds the pid of the process to signal. Required when method is SIGNAL.
- `signal` (Number) The signal to send to a process when a certificate should be reloaded. Required when method is SIGNAL.
- `unit_name` (String) The systemd unit name to reload when a certificate should be reloaded. Required when method is DBUS.
